OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Agiuntu a preferidos",
    "Removed from favorites" : "Bogadu dae preferidos",
    "You added {file} to your favorites" : "As agiuntu {file} a preferidos",
    "You removed {file} from your favorites" : "As bogadu {file} dae preferidos",
    "Favorites" : "Preferidos",
    "File changes" : "Modìficas de s'archìviu",
    "Created by {user}" : "Creadu dae {user}",
    "Changed by {user}" : "Modificadu dae {user}",
    "Deleted by {user}" : "Cantzelladu dae{user}",
    "Restored by {user}" : "Ripristinadu dae {user}",
    "Renamed by {user}" : "Torradu a numenare dae {user}",
    "Moved by {user}" : "Tramudadu dae {user}",
    "You created {file}" : "As creadu {file}",
    "You created an encrypted file in {file}" : "As creadu un'archìviu tzifradu in {file}",
    "{user} created {file}" : "{user} at creadu {file}",
    "{user} created an encrypted file in {file}" : "{user} at creadu un'archìviu tzifradu in {file}",
    "{file} was created in a public folder" : "{file} s'est creadu in una cartella pùblica",
    "You changed {file}" : "As cambiadu {file}",
    "You changed an encrypted file in {file}" : "As cambiadu un'archìviu tzifradu in {file}",
    "{user} changed {file}" : "{user} at cambiadu {file}",
    "{user} changed an encrypted file in {file}" : "{user} at cambiadu un'archìviu tzifradu in {file}",
    "You deleted {file}" : "As cantzelladu {file}",
    "You deleted an encrypted file in {file}" : "As cantzelladu un'archìviu tzifradu in {file}",
    "{user} deleted {file}" : "{user} at cantzelladu {file}",
    "{user} deleted an encrypted file in {file}" : "{user} at cantzelladu un'archìviu tzifradu in {file}",
    "You restored {file}" : "As recuperadu {file}",
    "{user} restored {file}" : "{user} at recuperadu {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "As torradu a numenare {oldfile} (hidden) cun {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "As torradu a numenare {oldfile} (hidden) cun {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "As torradu a numenare {oldfile} cun {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "As torradu a numenare {oldfile} cun {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} at torradu a numenare {oldfile} (hidden) cun {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} at torradu a numenare {oldfile} (hidden) cun {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} at torradu a numenare {oldfile} cun {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} at torradu a numenare {oldfile} cun {newfile}",
    "You moved {oldfile} to {newfile}" : "As tramudadu {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} at tramudadu {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Ant agiuntu o bogadu un'archìviu dae is <strong>preferidos</strong>",
    "Files" : "Archìvios",
    "A file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong> un'archìviu o una cartella",
    "A favorite file or folder has been <strong>changed</strong>" : "Ant <strong>cambiadu</strong>un'archìviu o una cartella preferida",
    "Upload (max. %s)" : "Càrriga (max. %s)",
    "Accept" : "Atzeta",
    "Reject" : "Refuda",
    "Incoming ownership transfer from {user}" : "Tràmuda de propriedade in intrada dae {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Boles atzetare {path}?\n\nNota: Su protzessu de tràmuda a pustis chi atzetas podet istentare fintzas un'ora.",
    "Ownership transfer failed" : "Tràmuda de propriedade faddida",
    "Your ownership transfer of {path} to {user} failed." : "Tràmuda de propriedade de {path} a {user} faddida.",
    "The ownership transfer of {path} from {user} failed." : "Tràmuda de propriedade de {path} dae {user} faddida.",
    "Ownership transfer done" : "Tràmuda de propriedade fata",
    "Your ownership transfer of {path} to {user} has completed." : "Tràmuda de propriedade de {path} a {user} cumpletada.",
    "The ownership transfer of {path} from {user} has completed." : "Tràmuda de propriedade de {path} dae {user} cumpletada.",
    "in %s" : "in %s",
    "File Management" : "Gestione archìvios",
    "Home" : "Pàgina printzipale",
    "Target folder does not exist any more" : "Sa cartella de destinatzione no esistit prus",
    "Reload current directory" : "Torra a carrigare sa cartella atuale",
    "Go to the \"{dir}\" directory" : "Bae a sa cartella \"{dir}\"",
    "Drag and drop files here to upload" : "Traga archìvios inoghe pro ddos carrigare",
    "Favorite" : "Preferidu",
    "Back" : "In segus",
    "Filename" : "Nùmene de s'archìviu",
    "Folder name" : "Nùmene de sa cartella",
    "Renamed \"{oldName}\" to \"{newName}\"" : "\"{oldName}\" s'est torradu a numenare comente \"{newName}\"",
    "Rename file" : "Torra a numenare s'archìviu",
    "Folder" : "Cartella",
    "Pending" : "In suspesu",
    "Clear filter" : "Lìmpia filtru",
    "Modified" : "Modificadu",
    "Type" : "Genia",
    "Name" : "Nùmene",
    "Size" : "Mannària",
    "Actions" : "Atziones",
    "(selected)" : "(seletzionados)",
    "List of files and folders." : "Lista de archìvios e cartellas.",
    "File not found" : "Archìviu no agatadu",
    "{count} selected" : "seletzionados: {count}",
    "{usedQuotaByte} used" : "{usedQuotaByte} impreadu",
    "{used} of {quota} used" : "{used} de {quota} impreadu",
    "{relative}% used" : "{relative}% impreadu",
    "Could not refresh storage stats" : "Impossìbile atualizare is istatìsticas de archiviatzione",
    "Your storage is full, files can not be updated or synced anymore!" : "S'archiviatzione est prena, non podes prus carrigare o sincronizare archìvios!",
    "New folder" : "Cartella noa",
    "Create new folder" : "Crea cartella noa",
    "Create" : "Crea",
    "Submit" : "Imbia",
    "Choose a file or folder to transfer" : "Sèbera un'archìviu o una cartella de tramudare",
    "Transfer" : "Tràmuda",
    "Transfer {path} to {userid}" : "Tràmuda {path} a {userid}",
    "Invalid path selected" : "Percursu seletzionadu non vàlidu",
    "Unknown error" : "Errore disconnotu",
    "Ownership transfer request sent" : "Dimanda de tràmuda de propriedade imbiada",
    "Cannot transfer ownership of a file or folder you do not own" : "Impossìbile tramudare sa propiedade de un'archìviu o de una cartella chi no sunt tuos",
    "Transfer ownership of a file or folder" : "Tràmuda propriedade de un'archìviu o una cartella",
    "Choose file or folder to transfer" : "Sèbera archìviu o cartella de tramudare",
    "Change" : "Càmbia",
    "New owner" : "Propriedade noa",
    "Select file or folder to link to" : "Seletziona un'archìviu o una cartella de ligongiare",
    "Choose {file}" : "Sèbera {file}",
    "Share" : "Cumpartzidura",
    "Shared by link" : "Cumpartzidu cun ligòngiu",
    "Shared" : "Cumpartzidu",
    "Switch to list view" : "Càmbia a sa vista de s'elencu",
    "Switch to grid view" : "Càmbia a vista de mosàicu",
    "Not enough free space" : "Non b'at logu lìberu",
    "Operation is blocked by access control" : "S'operatzione est blocada dae su controllu de intrada",
    "Error during upload: {message}" : "Errore in sa càrriga: {message}",
    "Unknown error during upload" : "Errore disconnotu durante sa càrriga",
    "Loading current folder" : "Carrighende sa cartella atuale",
    "No files in here" : "Perunu archìviu",
    "Upload some content or sync with your devices!" : "Càrriga cuntenutos o sincroniza cun is dispositivos tuos!",
    "Go back" : "In segus",
    "Views" : "Visualizatziones",
    "Files settings" : "Cunfiguratziones de archìvios",
    "File cannot be accessed" : "Impossìbile atzèdere a s'archìviu",
    "WebDAV URL copied to clipboard" : "URL WebDAV copiadu in punta de billete.",
    "Sort favorites first" : "Assenta cun is preferidos in antis",
    "Sort folders before files" : "Assenta cun is cartellas in antis de is archìvios",
    "Show hidden files" : "Mustra archìvios cuados",
    "Crop image previews" : "Retàllia anteprimas de s'immàgine",
    "Enable the grid view" : "Ativa sa visualizatzione de mosàicu",
    "Additional settings" : "Cunfiguratziones in agiunta",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "URL WebDAV",
    "Copy to clipboard" : "Còpia in is punta de billete",
    "Use this address to access your Files via WebDAV" : "Imprea custu indiritzu pro intrare in archìvios tràmite WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si as ativadu 2FA, depes creare e impreare una crae de s'aplicatzione noa incarchende inoghe.",
    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
    "Selection" : "Seletzione",
    "Navigation" : "Navigatzione",
    "View" : "Visualiza",
    "You" : "Tue",
    "Error while loading the file data" : "Errore in su carrigamentu de is datos de s'archìviu",
    "Remove from favorites" : "Boga dae preferidos",
    "Add to favorites" : "Agiunghe a preferidos",
    "Tags" : "Etichetas",
    "Blank" : "Isbòidu",
    "Unable to create new file from template" : "Non faghet a creare un'archìviu nou dae su modellu",
    "Pick a template for {name}" : "Sèbera unu modellu pro {name}",
    "Create a new file with the selected template" : "Crea un'archìviu nou cun su modellu seletzionadu",
    "Creating file" : "Creende s'archìviu",
    "Disconnect storage" : "Disconnete archiviatzione",
    "Delete permanently" : "Cantzella in manera definitiva",
    "Delete and unshare" : "Cantzella e firma sa cumpartzidura",
    "Delete file" : "Cantzella archìviu",
    "Delete folder" : "Cantzella sa cartella",
    "Delete" : "Cantzella",
    "Cancel" : "Annulla",
    "The file does not exist anymore" : "S'archìviu no esistit prus",
    "Choose destination" : "Sèbera unu destinu",
    "Copy to {target}" : "Còpia a {target}",
    "Copy" : "Còpia",
    "Move to {target}" : "Tràmuda a {target}",
    "Move" : "Tràmuda",
    "Move or copy operation failed" : "Errore in s'operatzione de tràmuda o de còpia",
    "Move or copy" : "Tràmuda o còpia",
    "Cancelled move or copy of \"{filename}\"." : "Operatzione de tràmuda o de còpia annullada pro s'archìviu: \"{filename}\".",
    "Cancelled move or copy operation" : "Operatzione de tràmuda o còpia annullada",
    "Open folder {displayName}" : "Aberi sa cartella {displayName}",
    "Open in Files" : "Aberi in Archìvios",
    "Open file locally" : "Aberi s'archìviu in locale",
    "Open locally" : "Aberi in locale",
    "Rename" : "Torra a numenare",
    "Open details" : "Aberi is detàllios",
    "View in folder" : "Visualiza in sa cartella",
    "Today" : "Oe ",
    "Last 7 days" : "Ùrtimas 7 dies",
    "Last 30 days" : "Ùrtimas 30 dies",
    "Documents" : "Documentos",
    "Folders" : "Cartellas",
    "Videos" : "Vìdeos",
    "Created new folder \"{name}\"" : "Cartella noa \"{name}\" creada",
    "Unable to initialize the templates directory" : "Non faghet a initzializare sa cartella de is modellos",
    "Templates" : "Modellos",
    "No files to upload" : "Perunu archìviu de carrigare",
    "Some files could not be uploaded" : "No at fatu a carrigare unos cantos archìvios",
    "Files uploaded successfully" : "Archìvios carrigados",
    "Some files could not be moved" : "No at fatu a tramudare carchi archìviu",
    "Upload cancelled" : "Carrigamentu annulladu",
    "This operation is forbidden" : "Custa operatzione no est permìtida",
    "This directory is unavailable, please check the logs or contact the administrator" : "Custa cartella no est a disponimentu, controlla is informes o cuntata s'amministratzione",
    "Storage is temporarily not available" : "S'archiviatzione immoe no est a disponimentu",
    "_%n file_::_%n files_" : ["%n archìviu","%n archìvios"],
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartellas"],
    "No favorites yet" : "Ancora perunu preferidu",
    "Files and folders you mark as favorite will show up here" : "Is archìvios e is cartellas chi marcas comente preferidos ant a aparèssere inoghe",
    "All files" : "Totu is archìvios",
    "List of your files and folders." : "Lista de is cartellas e is archìvios tuos.",
    "All folders" : "Totu is cartellas",
    "Personal files" : "Archìvios personales",
    "No personal files found" : "Perunu archìviu personale agatadu",
    "Recent" : "Reghente",
    "List of recently modified files and folders." : "Lista de cartellas e archìvios modificados de reghente.",
    "No recently modified files" : "Nissunu archìviu modificadu de reghente",
    "Files and folders you recently modified will show up here." : "Is cartellas e is archìvios chi apas modificadu de reghente ant a èssere mustrados inoghe.",
    "No entries found in this folder" : "Perunu elementu agatadu in custa cartella",
    "Select all" : "Seletziona totu",
    "Upload too large" : "Carrigamentu tropu mannu",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Is archìvios chi boles carrigare passant sa mannària màssima de carrigamentu de archìvios in custu serbidore.",
    "File could not be found" : "No at fatu a agatare s'archìviu",
    "Download" : "Iscàrriga",
    "Show list view" : "Mustra sa visualizatzione de lista",
    "Show grid view" : "Mustra sa visualizatzione de mosàicu",
    "Close" : "Serra",
    "Could not create folder \"{dir}\"" : "No at fatu a creare sa cartella \"{dir}\"",
    "This will stop your current uploads." : "Custu at a firmare is carrigamentos tuos atuales.",
    "Upload cancelled." : "Carrigamentu annulladu.",
    "Processing files …" : "Elaborende is archìvios ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No at fatu a carrigare {filename} ca est una cartella o tenet 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Non b'at logu, ses carrighende {size1} ma est abarradu isceti {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Sa cartella de destinatzione \"{dir}\" no esistit prus",
    "An unknown error has occurred" : "B'at àpidu un'errore disconnotu",
    "File could not be uploaded" : "Impossìbile carrigare s'archìviu",
    "Uploading …" : "Carrighende ...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Carrighende ... ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Su carrigamentu de s'elementu no est suportadu.",
    "Error when assembling chunks, status code {status}" : "Errore in s'assentada de is blocos, còdighe de istadu {status}",
    "Choose target folder" : "Sèbera cartella de destinatzione",
    "Set reminder" : "Cunfigura un'apuntu",
    "Edit locally" : "Modìfica in locale",
    "Open" : "Aberi",
    "Could not load info for file \"{file}\"" : "No at fatu a carrigare informatziones de s'archìviu \"{file}\"",
    "Details" : "Detàllios",
    "Please select tag(s) to add to the selection" : "Seletziona eticheta(s) pro agiùnghere a sa seletzione",
    "Apply tag(s) to selection" : "Àplica eticheta(s) a sa seletzione",
    "Select directory \"{dirName}\"" : "Seletziona sa cartella \"{dirName}\"",
    "Select file \"{fileName}\"" : "Seletziona s'archìviu \"{fileName}\"",
    "Unable to determine date" : "Non faghet a determinare sa data",
    "Could not move \"{file}\", target exists" : "No at fatu a tramudare \"{file}\", sa destinatzione esistit giai",
    "Could not move \"{file}\"" : "No at fatu a tramudare \"{file}\"",
    "copy" : "còpia",
    "Could not copy \"{file}\", target exists" : "No at fatu a copiare \"{file}\", sa destinatzione esistit giai",
    "Could not copy \"{file}\"" : "No at fatu a copiare \"{file}\"",
    "Copied {origin} inside {destination}" : "{origin} copiadu a intro de {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Copiados {origin} e {nbfiles} àteros archìvios a intro de {destination}",
    "{newName} already exists" : "{newName} esistit giai",
    "Could not rename \"{fileName}\", it does not exist any more" : "No at fatu a torrare a numenare \"{fileName}\", ca no esistit prus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Su nùmene \"{targetName}\" est giai impreadu in sa cartella \"{dir}\". Sèbera un'àteru nùmene.",
    "Could not rename \"{fileName}\"" : "No at fatu a torrare a numenare \"{fileName}\"",
    "Could not create file \"{file}\"" : "No at fatu a creare s'archìviu \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "No at fatu a creare s'archìviu \"{file}\" ca esitit giai",
    "Could not create folder \"{dir}\" because it already exists" : "No at fatu a creare sa cartella \"{dir}\" ca esistit giai",
    "Could not fetch file details \"{file}\"" : "No at fatu a recuperare is detàllios de s'archìviu \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Errore cantzellende s'archìviu \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Perunu resurtadu de chirca in àteras cartellas pro {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Inserta prus de duos caràteres pro chircare in àteras cartellas",
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["inclùdidu %n cuadu","inclùdidos %n cuados"],
    "You do not have permission to upload or create files here" : "Non tenes permissu pro carrigare o creare archìvios inoghe",
    "_Uploading %n file_::_Uploading %n files_" : ["Carrighende %n archìviu","Carrighende %n archìvios"],
    "New" : "Nou",
    "New file/folder menu" : "Menù de cartella o archìviu nou",
    "Select file range" : "Seletziona classe de archìviu",
    "{used}%" : "{used}%",
    "{used} used" : "{used} impreadu",
    "\"{name}\" is an invalid file name." : "\"{name}\" est unu nùmene de archìviu non vàlidu.",
    "File name cannot be empty." : "Su nùmene de s'archìviu non podet èssere bòidu.",
    "\"/\" is not allowed inside a file name." : "\"/\" no est permìtidu in unu nùmene de archìviu.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" no est una genia de archìviu permìtida",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "S'archiviatzione de {owner} est prena, non podes prus carrigare o sincronizare archìvios!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Sa cartella de grupu \"{mountPoint}\" est prena, non podes prus carrigare o sincronizare archìvios!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "S'archiviatzione de foras \"{mountPoint}\" est prena, non podes prus carrigare o sincronizare archìvios!",
    "Your storage is full, files cannot be updated or synced anymore!" : "S'archiviatzione est prena, non podes prus carrigare o sincronizare archìvios!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "S'archiviatzione de {owner} est giai prena ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Sa cartella de grupu \"{mountPoint}\" est giai prena ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "S'archiviatzione esterna \"{mountPoint}\" est giai prena ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "S'archiviatzione tua est giai prena ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["currispondet '{filter}'","currispondent '{filter}'"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Ligòngiu diretu copiadu (funtzionat isceti pro gente chi tenet atzessu a custu archìviu o cartella)",
    "Path" : "Percursu",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Preferidu",
    "Copy direct link (only works for people who have access to this file/folder)" : "Còpia su ligòngiu diretu (funtzionat isceti pro gente chi tenet atzessu a custu archìviu o cartella)",
    "Upload file" : "Càrriga archìviu",
    "Not favorited" : "Non preferidu",
    "An error occurred while trying to update the tags" : "B'at àpidu un'errore proende a agiornare is etichetas",
    "Storage informations" : "Informatziones de s'archiviatzione",
    "Choose file" : "Sèbera un'archìviu",
    "Go to the previous folder" : "Bae a sa cartella pretzedente",
    "Open the files app settings" : "Aberi sa cunfiguratzione de s'aplicatzione de archìvios",
    "Unable to change the favourite state of the file" : "Non faghet a cambiare s'istadu de preferidu de s'archìviu",
    "Create new templates folder" : "Crea una cartella de modellos noa",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartellas"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archìviu","{fileCount} archìvios"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archìviu e {folderCount} cartella","1 archìviu e {folderCount} cartellas"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} archìviu e 1 cartella","{fileCount} archìvios e 1 cartella"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} archìvios e {folderCount} cartellas",
    "List of favorites files and folders." : "Lista de cartellas e de archìvios preferidos.",
    "Personal Files" : "Archìvios personales",
    "Text file" : "Archìviu de testu",
    "New text file.txt" : "Archìviu de testu .txt nou",
    "Filter filenames…" : "Filtra nùmenes de archìviu..."
},
"nplurals=2; plural=(n != 1);");
